@@ -1,19 +1,5 @@
 var NAVTREEINDEX28 =
 {
-"globals_defs_u.html":[7,1,6,6],
-"globals_enum.html":[7,1,4],
-"globals_eval.html":[7,1,5],
-"globals_eval.html":[7,1,5,0],
-"globals_eval_r.html":[7,1,5,1],
-"globals_eval_s.html":[7,1,5,2],
-"globals_eval_t.html":[7,1,5,3],
-"globals_func.html":[7,1,1],
-"globals_func.html":[7,1,1,0],
-"globals_func_g.html":[7,1,1,1],
-"globals_func_o.html":[7,1,1,2],
-"globals_func_r.html":[7,1,1,3],
-"globals_func_s.html":[7,1,1,4],
-"globals_func_t.html":[7,1,1,5],
 "globals_func_u.html":[7,1,1,6],
 "globals_g.html":[7,1,0,2],
 "globals_h.html":[7,1,0,3],
