@@ -1,7 +1,7 @@
 var interfacecom_1_1sun_1_1star_1_1awt_1_1tab_1_1XTabPageContainerModel =
 [
-    [ "XContainer", "interfacecom_1_1sun_1_1star_1_1awt_1_1tab_1_1XTabPageContainerModel.html#a7a2fee03a55e1e4354eaea94bdaa4e4d", null ],
-    [ "XIndexContainer", "interfacecom_1_1sun_1_1star_1_1awt_1_1tab_1_1XTabPageContainerModel.html#a55a8285a19b6ec3383b31ff9d76b099b", null ],
+    [ "com::sun::star::container::XContainer", "interfacecom_1_1sun_1_1star_1_1awt_1_1tab_1_1XTabPageContainerModel.html#a7a2fee03a55e1e4354eaea94bdaa4e4d", null ],
+    [ "com::sun::star::container::XIndexContainer", "interfacecom_1_1sun_1_1star_1_1awt_1_1tab_1_1XTabPageContainerModel.html#a55a8285a19b6ec3383b31ff9d76b099b", null ],
     [ "createTabPage", "interfacecom_1_1sun_1_1star_1_1awt_1_1tab_1_1XTabPageContainerModel.html#ab27f9fe41d816a84b41c7bc61bb55f41", null ],
     [ "loadTabPage", "interfacecom_1_1sun_1_1star_1_1awt_1_1tab_1_1XTabPageContainerModel.html#abf4865a5e9ebbfeb349c5f8f5de6766c", null ]
 ];
\ No newline at end of file
