@@ -1,7 +1,7 @@
 var servicecom_1_1sun_1_1star_1_1table_1_1TableSortDescriptor =
 [
     [ "SortFields", "servicecom_1_1sun_1_1star_1_1table_1_1TableSortDescriptor.html#a29201edb2b9143cc355d0536935273ab", null ],
-    [ "SortDescriptor", "servicecom_1_1sun_1_1star_1_1table_1_1TableSortDescriptor.html#a232a116d2d39fd2f7f0e1ddc158975f6", null ],
+    [ "com::sun::star::util::SortDescriptor", "servicecom_1_1sun_1_1star_1_1table_1_1TableSortDescriptor.html#a232a116d2d39fd2f7f0e1ddc158975f6", null ],
     [ "ContainsHeader", "servicecom_1_1sun_1_1star_1_1table_1_1TableSortDescriptor.html#a5065e7c42974615d07286e452e171dc2", null ],
     [ "MaxFieldCount", "servicecom_1_1sun_1_1star_1_1table_1_1TableSortDescriptor.html#a3e2d176211cd10b1f02dd23d2161fade", null ],
     [ "Orientation", "servicecom_1_1sun_1_1star_1_1table_1_1TableSortDescriptor.html#ae58ad02c1344f960bf9f568693d8195f", null ]
